Class: Aws::ServerlessApplicationRepository::Client
- Inherits:
-
Seahorse::Client::Base
- Object
- Seahorse::Client::Base
- Aws::ServerlessApplicationRepository::Client
- Includes:
- ClientStubs
- Defined in:
- lib/aws-sdk-serverlessapplicationrepository/client.rb,
sig/client.rbs
Overview
An API client for ServerlessApplicationRepository. To construct a client, you need to configure a :region and :credentials.
client = Aws::ServerlessApplicationRepository::Client.new(
region: region_name,
credentials: credentials,
# ...
)
For details on configuring region and credentials see the developer guide.
See #initialize for a full list of supported configuration options.
Defined Under Namespace
Modules: _CreateApplicationResponseSuccess, _CreateApplicationVersionResponseSuccess, _CreateCloudFormationChangeSetResponseSuccess, _CreateCloudFormationTemplateResponseSuccess, _GetApplicationPolicyResponseSuccess, _GetApplicationResponseSuccess, _GetCloudFormationTemplateResponseSuccess, _ListApplicationDependenciesResponseSuccess, _ListApplicationVersionsResponseSuccess, _ListApplicationsResponseSuccess, _PutApplicationPolicyResponseSuccess, _UpdateApplicationResponseSuccess
Class Attribute Summary collapse
- .identifier ⇒ Object readonly private
API Operations collapse
-
#create_application(params = {}) ⇒ Types::CreateApplicationResponse
Creates an application, optionally including an AWS SAM file to create the first application version in the same call.
-
#create_application_version(params = {}) ⇒ Types::CreateApplicationVersionResponse
Creates an application version.
-
#create_cloud_formation_change_set(params = {}) ⇒ Types::CreateCloudFormationChangeSetResponse
Creates an AWS CloudFormation change set for the given application.
-
#create_cloud_formation_template(params = {}) ⇒ Types::CreateCloudFormationTemplateResponse
Creates an AWS CloudFormation template.
-
#delete_application(params = {}) ⇒ Struct
Deletes the specified application.
-
#get_application(params = {}) ⇒ Types::GetApplicationResponse
Gets the specified application.
-
#get_application_policy(params = {}) ⇒ Types::GetApplicationPolicyResponse
Retrieves the policy for the application.
-
#get_cloud_formation_template(params = {}) ⇒ Types::GetCloudFormationTemplateResponse
Gets the specified AWS CloudFormation template.
-
#list_application_dependencies(params = {}) ⇒ Types::ListApplicationDependenciesResponse
Retrieves the list of applications nested in the containing application.
-
#list_application_versions(params = {}) ⇒ Types::ListApplicationVersionsResponse
Lists versions for the specified application.
-
#list_applications(params = {}) ⇒ Types::ListApplicationsResponse
Lists applications owned by the requester.
-
#put_application_policy(params = {}) ⇒ Types::PutApplicationPolicyResponse
Sets the permission policy for an application.
-
#unshare_application(params = {}) ⇒ Struct
Unshares an application from an AWS Organization.
-
#update_application(params = {}) ⇒ Types::UpdateApplicationResponse
Updates the specified application.
Class Method Summary collapse
- .errors_module ⇒ Object private
- .new ⇒ Object
Instance Method Summary collapse
- #build_request(operation_name, params = {}) ⇒ Object private
-
#initialize(options) ⇒ Client
constructor
A new instance of Client.
- #waiter_names ⇒ Object deprecated private Deprecated.
Constructor Details
#initialize(options) ⇒ Client
Returns a new instance of Client.
471 472 473 |
# File 'lib/aws-sdk-serverlessapplicationrepository/client.rb', line 471 def initialize(*args) super end |
Class Attribute Details
.identifier ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1306 1307 1308 |
# File 'lib/aws-sdk-serverlessapplicationrepository/client.rb', line 1306 def identifier @identifier end |
Class Method Details
.errors_module ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1309 1310 1311 |
# File 'lib/aws-sdk-serverlessapplicationrepository/client.rb', line 1309 def errors_module Errors end |
.new ⇒ Object
14 |
# File 'sig/client.rbs', line 14
def self.new: (
|
Instance Method Details
#build_request(operation_name, params = {}) ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1279 1280 1281 1282 1283 1284 1285 1286 1287 1288 1289 1290 1291 1292 1293 1294 1295 |
# File 'lib/aws-sdk-serverlessapplicationrepository/client.rb', line 1279 def build_request(operation_name, params = {}) handlers = @handlers.for(operation_name) tracer = config.telemetry_provider.tracer_provider.tracer( Aws::Telemetry.module_to_tracer_name('Aws::ServerlessApplicationRepository') ) context = Seahorse::Client::RequestContext.new( operation_name: operation_name, operation: config.api.operation(operation_name), client: self, params: params, config: config, tracer: tracer ) context[:gem_name] = 'aws-sdk-serverlessapplicationrepository' context[:gem_version] = '1.93.0' Seahorse::Client::Request.new(handlers, context) end |
#create_application(params = {}) ⇒ Types::CreateApplicationResponse
Creates an application, optionally including an AWS SAM file to create the first application version in the same call.
98 |
# File 'sig/client.rbs', line 98
def create_application: (
|
#create_application_version(params = {}) ⇒ Types::CreateApplicationVersionResponse
Creates an application version.
130 |
# File 'sig/client.rbs', line 130
def create_application_version: (
|
#create_cloud_formation_change_set(params = {}) ⇒ Types::CreateCloudFormationChangeSetResponse
Creates an AWS CloudFormation change set for the given application.
148 |
# File 'sig/client.rbs', line 148
def create_cloud_formation_change_set: (
|
#create_cloud_formation_template(params = {}) ⇒ Types::CreateCloudFormationTemplateResponse
Creates an AWS CloudFormation template.
194 |
# File 'sig/client.rbs', line 194
def create_cloud_formation_template: (
|
#delete_application(params = {}) ⇒ Struct
Deletes the specified application.
201 |
# File 'sig/client.rbs', line 201
def delete_application: (
|
#get_application(params = {}) ⇒ Types::GetApplicationResponse
Gets the specified application.
223 |
# File 'sig/client.rbs', line 223
def get_application: (
|
#get_application_policy(params = {}) ⇒ Types::GetApplicationPolicyResponse
Retrieves the policy for the application.
234 |
# File 'sig/client.rbs', line 234
def get_application_policy: (
|
#get_cloud_formation_template(params = {}) ⇒ Types::GetCloudFormationTemplateResponse
Gets the specified AWS CloudFormation template.
250 |
# File 'sig/client.rbs', line 250
def get_cloud_formation_template: (
|
#list_application_dependencies(params = {}) ⇒ Types::ListApplicationDependenciesResponse
Retrieves the list of applications nested in the containing application.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
262 |
# File 'sig/client.rbs', line 262
def list_application_dependencies: (
|
#list_application_versions(params = {}) ⇒ Types::ListApplicationVersionsResponse
Lists versions for the specified application.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
276 |
# File 'sig/client.rbs', line 276
def list_application_versions: (
|
#list_applications(params = {}) ⇒ Types::ListApplicationsResponse
Lists applications owned by the requester.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
289 |
# File 'sig/client.rbs', line 289
def list_applications: (
|
#put_application_policy(params = {}) ⇒ Types::PutApplicationPolicyResponse
Sets the permission policy for an application. For the list of actions supported for this operation, see Application Permissions .
300 |
# File 'sig/client.rbs', line 300
def put_application_policy: (
|
#unshare_application(params = {}) ⇒ Struct
Unshares an application from an AWS Organization.
This operation can be called only from the organization's master account.
314 |
# File 'sig/client.rbs', line 314
def unshare_application: (
|
#update_application(params = {}) ⇒ Types::UpdateApplicationResponse
Updates the specified application.
337 |
# File 'sig/client.rbs', line 337
def update_application: (
|
#waiter_names ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1299 1300 1301 |
# File 'lib/aws-sdk-serverlessapplicationrepository/client.rb', line 1299 def waiter_names [] end |