Module: Aws::ServerlessApplicationRepository::Errors
- Extended by:
- Errors::DynamicErrors
- Defined in:
- lib/aws-sdk-serverlessapplicationrepository/errors.rb,
sig/errors.rbs
Overview
When ServerlessApplicationRepository returns an error response, the Ruby SDK constructs and raises an error. These errors all extend Aws::ServerlessApplicationRepository::Errors::ServiceError < Errors::ServiceError
You can rescue all ServerlessApplicationRepository errors using ServiceError:
begin
# do stuff
rescue Aws::ServerlessApplicationRepository::Errors::ServiceError
# rescues all ServerlessApplicationRepository API errors
end
Request Context
ServiceError objects have a #context method that returns information about the request that generated the error. See Seahorse::Client::RequestContext for more information.
Error Classes
- BadRequestException
- ConflictException
- ForbiddenException
- InternalServerErrorException
- NotFoundException
- TooManyRequestsException
Additionally, error classes are dynamically generated for service errors based on the error code if they are not defined above.
Defined Under Namespace
Classes: BadRequestException, ConflictException, ForbiddenException, InternalServerErrorException, NotFoundException, ServiceError, TooManyRequestsException