Class: Aws::ServerlessApplicationRepository::Client
- Inherits:
-
Seahorse::Client::Base
- Object
- Seahorse::Client::Base
- Aws::ServerlessApplicationRepository::Client
- Includes:
- ClientStubs
- Defined in:
- lib/aws-sdk-serverlessapplicationrepository/client.rb
Overview
An API client for ServerlessApplicationRepository. To construct a client, you need to configure a ‘:region` and `:credentials`.
client = Aws::ServerlessApplicationRepository::Client.new(
region: region_name,
credentials: credentials,
# ...
)
For details on configuring region and credentials see the [developer guide](/sdk-for-ruby/v3/developer-guide/setup-config.html).
See #initialize for a full list of supported configuration options.
Class Attribute Summary collapse
- .identifier ⇒ Object readonly private
API Operations collapse
-
#create_application(params = {}) ⇒ Types::CreateApplicationResponse
Creates an application, optionally including an AWS SAM file to create the first application version in the same call.
-
#create_application_version(params = {}) ⇒ Types::CreateApplicationVersionResponse
Creates an application version.
-
#create_cloud_formation_change_set(params = {}) ⇒ Types::CreateCloudFormationChangeSetResponse
Creates an AWS CloudFormation change set for the given application.
-
#create_cloud_formation_template(params = {}) ⇒ Types::CreateCloudFormationTemplateResponse
Creates an AWS CloudFormation template.
-
#delete_application(params = {}) ⇒ Struct
Deletes the specified application.
-
#get_application(params = {}) ⇒ Types::GetApplicationResponse
Gets the specified application.
-
#get_application_policy(params = {}) ⇒ Types::GetApplicationPolicyResponse
Retrieves the policy for the application.
-
#get_cloud_formation_template(params = {}) ⇒ Types::GetCloudFormationTemplateResponse
Gets the specified AWS CloudFormation template.
-
#list_application_dependencies(params = {}) ⇒ Types::ListApplicationDependenciesResponse
Retrieves the list of applications nested in the containing application.
-
#list_application_versions(params = {}) ⇒ Types::ListApplicationVersionsResponse
Lists versions for the specified application.
-
#list_applications(params = {}) ⇒ Types::ListApplicationsResponse
Lists applications owned by the requester.
-
#put_application_policy(params = {}) ⇒ Types::PutApplicationPolicyResponse
Sets the permission policy for an application.
-
#unshare_application(params = {}) ⇒ Struct
Unshares an application from an AWS Organization.
-
#update_application(params = {}) ⇒ Types::UpdateApplicationResponse
Updates the specified application.
Class Method Summary collapse
- .errors_module ⇒ Object private
Instance Method Summary collapse
- #build_request(operation_name, params = {}) ⇒ Object private
-
#initialize(options) ⇒ Client
constructor
A new instance of Client.
- #waiter_names ⇒ Object deprecated private Deprecated.
Constructor Details
#initialize(options) ⇒ Client
Returns a new instance of Client.
471 472 473 |
# File 'lib/aws-sdk-serverlessapplicationrepository/client.rb', line 471 def initialize(*args) super end |
Class Attribute Details
.identifier ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1306 1307 1308 |
# File 'lib/aws-sdk-serverlessapplicationrepository/client.rb', line 1306 def identifier @identifier end |
Class Method Details
.errors_module ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1309 1310 1311 |
# File 'lib/aws-sdk-serverlessapplicationrepository/client.rb', line 1309 def errors_module Errors end |
Instance Method Details
#build_request(operation_name, params = {}) ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1279 1280 1281 1282 1283 1284 1285 1286 1287 1288 1289 1290 1291 1292 1293 1294 1295 |
# File 'lib/aws-sdk-serverlessapplicationrepository/client.rb', line 1279 def build_request(operation_name, params = {}) handlers = @handlers.for(operation_name) tracer = config.telemetry_provider.tracer_provider.tracer( Aws::Telemetry.module_to_tracer_name('Aws::ServerlessApplicationRepository') ) context = Seahorse::Client::RequestContext.new( operation_name: operation_name, operation: config.api.operation(operation_name), client: self, params: params, config: config, tracer: tracer ) context[:gem_name] = 'aws-sdk-serverlessapplicationrepository' context[:gem_version] = '1.92.0' Seahorse::Client::Request.new(handlers, context) end |
#create_application(params = {}) ⇒ Types::CreateApplicationResponse
Creates an application, optionally including an AWS SAM file to create the first application version in the same call.
591 592 593 594 |
# File 'lib/aws-sdk-serverlessapplicationrepository/client.rb', line 591 def create_application(params = {}, = {}) req = build_request(:create_application, params) req.send_request() end |
#create_application_version(params = {}) ⇒ Types::CreateApplicationVersionResponse
Creates an application version.
665 666 667 668 |
# File 'lib/aws-sdk-serverlessapplicationrepository/client.rb', line 665 def create_application_version(params = {}, = {}) req = build_request(:create_application_version, params) req.send_request() end |
#create_cloud_formation_change_set(params = {}) ⇒ Types::CreateCloudFormationChangeSetResponse
Creates an AWS CloudFormation change set for the given application.
755 756 757 758 |
# File 'lib/aws-sdk-serverlessapplicationrepository/client.rb', line 755 def create_cloud_formation_change_set(params = {}, = {}) req = build_request(:create_cloud_formation_change_set, params) req.send_request() end |
#create_cloud_formation_template(params = {}) ⇒ Types::CreateCloudFormationTemplateResponse
Creates an AWS CloudFormation template.
797 798 799 800 |
# File 'lib/aws-sdk-serverlessapplicationrepository/client.rb', line 797 def create_cloud_formation_template(params = {}, = {}) req = build_request(:create_cloud_formation_template, params) req.send_request() end |
#delete_application(params = {}) ⇒ Struct
Deletes the specified application.
818 819 820 821 |
# File 'lib/aws-sdk-serverlessapplicationrepository/client.rb', line 818 def delete_application(params = {}, = {}) req = build_request(:delete_application, params) req.send_request() end |
#get_application(params = {}) ⇒ Types::GetApplicationResponse
Gets the specified application.
897 898 899 900 |
# File 'lib/aws-sdk-serverlessapplicationrepository/client.rb', line 897 def get_application(params = {}, = {}) req = build_request(:get_application, params) req.send_request() end |
#get_application_policy(params = {}) ⇒ Types::GetApplicationPolicyResponse
Retrieves the policy for the application.
931 932 933 934 |
# File 'lib/aws-sdk-serverlessapplicationrepository/client.rb', line 931 def get_application_policy(params = {}, = {}) req = build_request(:get_application_policy, params) req.send_request() end |
#get_cloud_formation_template(params = {}) ⇒ Types::GetCloudFormationTemplateResponse
Gets the specified AWS CloudFormation template.
973 974 975 976 |
# File 'lib/aws-sdk-serverlessapplicationrepository/client.rb', line 973 def get_cloud_formation_template(params = {}, = {}) req = build_request(:get_cloud_formation_template, params) req.send_request() end |
#list_application_dependencies(params = {}) ⇒ Types::ListApplicationDependenciesResponse
Retrieves the list of applications nested in the containing application.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1016 1017 1018 1019 |
# File 'lib/aws-sdk-serverlessapplicationrepository/client.rb', line 1016 def list_application_dependencies(params = {}, = {}) req = build_request(:list_application_dependencies, params) req.send_request() end |
#list_application_versions(params = {}) ⇒ Types::ListApplicationVersionsResponse
Lists versions for the specified application.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1057 1058 1059 1060 |
# File 'lib/aws-sdk-serverlessapplicationrepository/client.rb', line 1057 def list_application_versions(params = {}, = {}) req = build_request(:list_application_versions, params) req.send_request() end |
#list_applications(params = {}) ⇒ Types::ListApplicationsResponse
Lists applications owned by the requester.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1100 1101 1102 1103 |
# File 'lib/aws-sdk-serverlessapplicationrepository/client.rb', line 1100 def list_applications(params = {}, = {}) req = build_request(:list_applications, params) req.send_request() end |
#put_application_policy(params = {}) ⇒ Types::PutApplicationPolicyResponse
Sets the permission policy for an application. For the list of actions supported for this operation, see [Application Permissions] .
1149 1150 1151 1152 |
# File 'lib/aws-sdk-serverlessapplicationrepository/client.rb', line 1149 def put_application_policy(params = {}, = {}) req = build_request(:put_application_policy, params) req.send_request() end |
#unshare_application(params = {}) ⇒ Struct
Unshares an application from an AWS Organization.
This operation can be called only from the organization’s master account.
1176 1177 1178 1179 |
# File 'lib/aws-sdk-serverlessapplicationrepository/client.rb', line 1176 def unshare_application(params = {}, = {}) req = build_request(:unshare_application, params) req.send_request() end |
#update_application(params = {}) ⇒ Types::UpdateApplicationResponse
Updates the specified application.
1270 1271 1272 1273 |
# File 'lib/aws-sdk-serverlessapplicationrepository/client.rb', line 1270 def update_application(params = {}, = {}) req = build_request(:update_application, params) req.send_request() end |
#waiter_names ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1299 1300 1301 |
# File 'lib/aws-sdk-serverlessapplicationrepository/client.rb', line 1299 def waiter_names [] end |